<?php

/**
 * @author    Hennes Hervé <contact@h-hennes.fr>
 * @copyright Since 2013 Hennes Hervé
 * @license   http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 *  https://www.h-hennes.fr/blog/
 */

class HhProduct extends Module
{

    public function __construct()
    {
        $this->name = 'hhproduct';
        $this->tab = 'others';
        $this->author = 'hhennes';
        $this->version = '0.1.0';
        $this->need_instance = 0;
        $this->bootstrap = true;

        parent::__construct();

        $this->displayName = $this->l('hhproduct');
        $this->description = $this->l('add new fields to product');
        $this->ps_versions_compliancy = ['min' => '1.7.1', 'max' => _PS_VERSION_];
    }

    /**
     * Installation du module
     *
     * @return bool
     */
    public function install()
    {
        if (!parent::install()
            || !$this->_installSql()
            || !$this->registerHook('displayAdminProductsMainStepLeftColumnMiddle')
        ) {
            return false;
        }

        return true;
    }

    /**
     * Désinstallation du module
     *
     * @return bool
     */
    public function uninstall()
    {
        return parent::uninstall()
            && $this->_unInstallSql();
    }

    /**
     * Modifications sql du module
     *
     * @return boolean
     */
    protected function _installSql()
    {
        $sqlInstall = "ALTER TABLE " . _DB_PREFIX_ . "product "
            . "ADD custom_field VARCHAR(255) NULL";
        $sqlInstallLang = "ALTER TABLE " . _DB_PREFIX_ . "product_lang "
            . "ADD custom_field_lang VARCHAR(255) NULL,"
            . "ADD custom_field_lang_wysiwyg TEXT NULL";

        $returnSql = Db::getInstance()->execute($sqlInstall);
        $returnSqlLang = Db::getInstance()->execute($sqlInstallLang);

        return $returnSql && $returnSqlLang;
    }

    /**
     * Suppression des modifications sql du module
     *
     * @return boolean
     */
    protected function _unInstallSql()
    {
        $sqlInstall = "ALTER TABLE " . _DB_PREFIX_ . "product "
            . "DROP custom_field";
        $sqlInstallLang = "ALTER TABLE " . _DB_PREFIX_ . "product_lang "
            . "DROP custom_field_lang,DROP custom_field_lang_wysiwyg";

        $returnSql = Db::getInstance()->execute($sqlInstall);
        $returnSqlLang = Db::getInstance()->execute($sqlInstallLang);

        return $returnSql && $returnSqlLang;
    }

    /**
     * Affichage des informations supplémentaires sur la fiche produit
     *
     * Pour les autres hooks disponibles voir le tutoriel :
     * https://www.h-hennes.fr/blog/2017/10/19/prestashop-1-7-ajouter-des-champs-produit/
     *
     * @param array $params
     * @return string
     */
    public function hookDisplayAdminProductsMainStepLeftColumnMiddle($params)
    {
        $product = new Product($params['id_product']);
        $languages = Language::getLanguages(true);
        $this->context->smarty->assign(array(
                'custom_field' => $product->custom_field,
                'languages' => $languages,
                'custom_field_lang' => $product->custom_field_lang,
                'custom_field_lang_wysiwyg' => $product->custom_field_lang_wysiwyg,
                'default_language' => $this->context->employee->id_lang,
            )
        );

        return $this->display(__FILE__, 'views/templates/hook/extrafields.tpl');
    }

}
